aboutsummaryrefslogtreecommitdiffstats
path: root/Game/Code/Classes/ULyrics.pas
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--Game/Code/Classes/ULyrics.pas6
1 files changed, 3 insertions, 3 deletions
diff --git a/Game/Code/Classes/ULyrics.pas b/Game/Code/Classes/ULyrics.pas
index 38bc1e7a..b542b5f6 100644
--- a/Game/Code/Classes/ULyrics.pas
+++ b/Game/Code/Classes/ULyrics.pas
@@ -114,7 +114,7 @@ type
Constructor Create; overload;
Constructor Create(ULX,ULY,ULW,ULS,LLX,LLY,LLW,LLS:Real); overload;
Procedure LoadTextures;
- Destructor Free;
+ Destructor Destroy; override;
end;
implementation
@@ -190,9 +190,9 @@ end;
//---------------
// Free - Frees Memory
//---------------
-Destructor TLyricEngine.Free;
+Destructor TLyricEngine.Destroy;
begin
end;
@@ -190,9 +190,9 @@ end;
//---------------
-// Free - Frees Memory
+// Destroy - Frees Memory
//---------------